# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.common.criteria_pb2 import (
    KeywordInfo as google___ads___googleads___v2___common___criteria_pb2___KeywordInfo,
)

from google.ads.google_ads.v2.proto.common.extensions_pb2 import (
    CallFeedItem as google___ads___googleads___v2___common___extensions_pb2___CallFeedItem,
    CalloutFeedItem as google___ads___googleads___v2___common___extensions_pb2___CalloutFeedItem,
    SitelinkFeedItem as google___ads___googleads___v2___common___extensions_pb2___SitelinkFeedItem,
)

from google.ads.google_ads.v2.proto.enums.keyword_match_type_pb2 import (
    KeywordMatchTypeEnum as google___ads___googleads___v2___enums___keyword_match_type_pb2___KeywordMatchTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.recommendation_type_pb2 import (
    RecommendationTypeEnum as google___ads___googleads___v2___enums___recommendation_type_pb2___RecommendationTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.target_cpa_opt_in_recommendation_goal_pb2 import (
    TargetCpaOptInRecommendationGoalEnum as google___ads___googleads___v2___enums___target_cpa_opt_in_recommendation_goal_pb2___TargetCpaOptInRecommendationGoalEnum,
)

from google.ads.google_ads.v2.proto.resources.ad_pb2 import (
    Ad as google___ads___googleads___v2___resources___ad_pb2___Ad,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
    Union as typing___Union,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int
if sys.version_info < (3,):
    builtin___buffer = buffer
    builtin___unicode = unicode


class Recommendation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class RecommendationImpact(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def base_metrics(self) -> global___Recommendation.RecommendationMetrics: ...

        @property
        def potential_metrics(self) -> global___Recommendation.RecommendationMetrics: ...

        def __init__(self,
            *,
            base_metrics : typing___Optional[global___Recommendation.RecommendationMetrics] = None,
            potential_metrics : typing___Optional[global___Recommendation.RecommendationMetrics] = None,
            ) -> None: ...
        if sys.version_info >= (3,):
            @classmethod
            def FromString(cls, s: builtin___bytes) -> Recommendation.RecommendationImpact: ...
        else:
            @classmethod
            def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Recommendation.RecommendationImpact: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def HasField(self, field_name: typing_extensions___Literal[u"base_metrics",b"base_metrics",u"potential_metrics",b"potential_metrics"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"base_metrics",b"base_metrics",u"potential_metrics",b"potential_metrics"]) -> None: ...
    global___RecommendationImpact = RecommendationImpact

    class RecommendationMetrics(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def impressions(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

        @property
        def clicks(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

        @property
        def cost_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        @property
        def conversions(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

        @property
        def video_views(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

        def __init__(self,
            *,
            impressions : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
            clicks : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
            cost_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            conversions : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
            video_views : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
            ) -> None: ...
        if sys.version_info >= (3,):
            @classmethod
            def FromString(cls, s: builtin___bytes) -> Recommendation.RecommendationMetrics: ...
        else:
            @classmethod
            def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Recommendation.RecommendationMetrics: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def HasField(self, field_name: typing_extensions___Literal[u"clicks",b"clicks",u"conversions",b"conversions",u"cost_micros",b"cost_micros",u"impressions",b"impressions",u"video_views",b"video_views"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"clicks",b"clicks",u"conversions",b"conversions",u"cost_micros",b"cost_micros",u"impressions",b"impressions",u"video_views",b"video_views"]) -> None: ...
    global___RecommendationMetrics = RecommendationMetrics

    class CampaignBudgetRecommendation(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        class CampaignBudgetRecommendationOption(google___protobuf___message___Message):
            DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

            @property
            def budget_amount_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

            @property
            def impact(self) -> global___Recommendation.RecommendationImpact: ...

            def __init__(self,
                *,
                budget_amount_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
                impact : typing___Optional[global___Recommendation.RecommendationImpact] = None,
                ) -> None: ...
            if sys.version_info >= (3,):
                @classmethod
                def FromString(cls, s: builtin___bytes) -> Recommendation.CampaignBudgetRecommendation.CampaignBudgetRecommendationOption: ...
            else:
                @classmethod
                def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Recommendation.CampaignBudgetRecommendation.CampaignBudgetRecommendationOption: ...
            def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
            def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
            def HasField(self, field_name: typing_extensions___Literal[u"budget_amount_micros",b"budget_amount_micros",u"impact",b"impact"]) -> builtin___bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"budget_amount_micros",b"budget_amount_micros",u"impact",b"impact"]) -> None: ...
        global___CampaignBudgetRecommendationOption = CampaignBudgetRecommendationOption


        @property
        def current_budget_amount_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        @property
        def recommended_budget_amount_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        @property
        def budget_options(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[global___Recommendation.CampaignBudgetRecommendation.CampaignBudgetRecommendationOption]: ...

        def __init__(self,
            *,
            current_budget_amount_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            recommended_budget_amount_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            budget_options : typing___Optional[typing___Iterable[global___Recommendation.CampaignBudgetRecommendation.CampaignBudgetRecommendationOption]] = None,
            ) -> None: ...
        if sys.version_info >= (3,):
            @classmethod
            def FromString(cls, s: builtin___bytes) -> Recommendation.CampaignBudgetRecommendation: ...
        else:
            @classmethod
            def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Recommendation.CampaignBudgetRecommendation: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def HasField(self, field_name: typing_extensions___Literal[u"current_budget_amount_micros",b"current_budget_amount_micros",u"recommended_budget_amount_micros",b"recommended_budget_amount_micros"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"budget_options",b"budget_options",u"current_budget_amount_micros",b"current_budget_amount_micros",u"recommended_budget_amount_micros",b"recommended_budget_amount_micros"]) -> None: ...
    global___CampaignBudgetRecommendation = CampaignBudgetRecommendation

    class KeywordRecommendation(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def keyword(self) -> google___ads___googleads___v2___common___criteria_pb2___KeywordInfo: ...

        @property
        def recommended_cpc_bid_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        def __init__(self,
            *,
            keyword : typing___Optional[google___ads___googleads___v2___common___criteria_pb2___KeywordInfo] = None,
            recommended_cpc_bid_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            ) -> None: ...
        if sys.version_info >= (3,):
            @classmethod
            def FromString(cls, s: builtin___bytes) -> Recommendation.KeywordRecommendation: ...
        else:
            @classmethod
            def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Recommendation.KeywordRecommendation: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def HasField(self, field_name: typing_extensions___Literal[u"keyword",b"keyword",u"recommended_cpc_bid_micros",b"recommended_cpc_bid_micros"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"keyword",b"keyword",u"recommended_cpc_bid_micros",b"recommended_cpc_bid_micros"]) -> None: ...
    global___KeywordRecommendation = KeywordRecommendation

    class MoveUnusedBudgetRecommendation(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def excess_campaign_budget(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def budget_recommendation(self) -> global___Recommendation.CampaignBudgetRecommendation: ...

        def __init__(self,
            *,
            excess_campaign_budget : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            budget_recommendation : typing___Optional[global___Recommendation.CampaignBudgetRecommendation] = None,
            ) -> None: ...
        if sys.version_info >= (3,):
            @classmethod
            def FromString(cls, s: builtin___bytes) -> Recommendation.MoveUnusedBudgetRecommendation: ...
        else:
            @classmethod
            def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Recommendation.MoveUnusedBudgetRecommendation: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def HasField(self, field_name: typing_extensions___Literal[u"budget_recommendation",b"budget_recommendation",u"excess_campaign_budget",b"excess_campaign_budget"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"budget_recommendation",b"budget_recommendation",u"excess_campaign_budget",b"excess_campaign_budget"]) -> None: ...
    global___MoveUnusedBudgetRecommendation = MoveUnusedBudgetRecommendation

    class TextAdRecommendation(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def ad(self) -> google___ads___googleads___v2___resources___ad_pb2___Ad: ...

        @property
        def creation_date(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def auto_apply_date(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        def __init__(self,
            *,
            ad : typing___Optional[google___ads___googleads___v2___resources___ad_pb2___Ad] = None,
            creation_date : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            auto_apply_date : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            ) -> None: ...
        if sys.version_info >= (3,):
            @classmethod
            def FromString(cls, s: builtin___bytes) -> Recommendation.TextAdRecommendation: ...
        else:
            @classmethod
            def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Recommendation.TextAdRecommendation: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def HasField(self, field_name: typing_extensions___Literal[u"ad",b"ad",u"auto_apply_date",b"auto_apply_date",u"creation_date",b"creation_date"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad",b"ad",u"auto_apply_date",b"auto_apply_date",u"creation_date",b"creation_date"]) -> None: ...
    global___TextAdRecommendation = TextAdRecommendation

    class SearchPartnersOptInRecommendation(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        def __init__(self,
            ) -> None: ...
        if sys.version_info >= (3,):
            @classmethod
            def FromString(cls, s: builtin___bytes) -> Recommendation.SearchPartnersOptInRecommendation: ...
        else:
            @classmethod
            def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Recommendation.SearchPartnersOptInRecommendation: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    global___SearchPartnersOptInRecommendation = SearchPartnersOptInRecommendation

    class MaximizeClicksOptInRecommendation(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def recommended_budget_amount_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        def __init__(self,
            *,
            recommended_budget_amount_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            ) -> None: ...
        if sys.version_info >= (3,):
            @classmethod
            def FromString(cls, s: builtin___bytes) -> Recommendation.MaximizeClicksOptInRecommendation: ...
        else:
            @classmethod
            def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Recommendation.MaximizeClicksOptInRecommendation: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def HasField(self, field_name: typing_extensions___Literal[u"recommended_budget_amount_micros",b"recommended_budget_amount_micros"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"recommended_budget_amount_micros",b"recommended_budget_amount_micros"]) -> None: ...
    global___MaximizeClicksOptInRecommendation = MaximizeClicksOptInRecommendation

    class CallExtensionRecommendation(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def recommended_extensions(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v2___common___extensions_pb2___CallFeedItem]: ...

        def __init__(self,
            *,
            recommended_extensions : typing___Optional[typing___Iterable[google___ads___googleads___v2___common___extensions_pb2___CallFeedItem]] = None,
            ) -> None: ...
        if sys.version_info >= (3,):
            @classmethod
            def FromString(cls, s: builtin___bytes) -> Recommendation.CallExtensionRecommendation: ...
        else:
            @classmethod
            def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Recommendation.CallExtensionRecommendation: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"recommended_extensions",b"recommended_extensions"]) -> None: ...
    global___CallExtensionRecommendation = CallExtensionRecommendation

    class TargetCpaOptInRecommendation(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        class TargetCpaOptInRecommendationOption(google___protobuf___message___Message):
            DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
            goal = ... # type: google___ads___googleads___v2___enums___target_cpa_opt_in_recommendation_goal_pb2___TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoal

            @property
            def target_cpa_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

            @property
            def required_campaign_budget_amount_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

            @property
            def impact(self) -> global___Recommendation.RecommendationImpact: ...

            def __init__(self,
                *,
                goal : typing___Optional[google___ads___googleads___v2___enums___target_cpa_opt_in_recommendation_goal_pb2___TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoal] = None,
                target_cpa_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
                required_campaign_budget_amount_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
                impact : typing___Optional[global___Recommendation.RecommendationImpact] = None,
                ) -> None: ...
            if sys.version_info >= (3,):
                @classmethod
                def FromString(cls, s: builtin___bytes) -> Recommendation.TargetCpaOptInRecommendation.TargetCpaOptInRecommendationOption: ...
            else:
                @classmethod
                def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Recommendation.TargetCpaOptInRecommendation.TargetCpaOptInRecommendationOption: ...
            def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
            def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
            def HasField(self, field_name: typing_extensions___Literal[u"impact",b"impact",u"required_campaign_budget_amount_micros",b"required_campaign_budget_amount_micros",u"target_cpa_micros",b"target_cpa_micros"]) -> builtin___bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"goal",b"goal",u"impact",b"impact",u"required_campaign_budget_amount_micros",b"required_campaign_budget_amount_micros",u"target_cpa_micros",b"target_cpa_micros"]) -> None: ...
        global___TargetCpaOptInRecommendationOption = TargetCpaOptInRecommendationOption


        @property
        def options(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[global___Recommendation.TargetCpaOptInRecommendation.TargetCpaOptInRecommendationOption]: ...

        @property
        def recommended_target_cpa_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        def __init__(self,
            *,
            options : typing___Optional[typing___Iterable[global___Recommendation.TargetCpaOptInRecommendation.TargetCpaOptInRecommendationOption]] = None,
            recommended_target_cpa_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            ) -> None: ...
        if sys.version_info >= (3,):
            @classmethod
            def FromString(cls, s: builtin___bytes) -> Recommendation.TargetCpaOptInRecommendation: ...
        else:
            @classmethod
            def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Recommendation.TargetCpaOptInRecommendation: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def HasField(self, field_name: typing_extensions___Literal[u"recommended_target_cpa_micros",b"recommended_target_cpa_micros"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"options",b"options",u"recommended_target_cpa_micros",b"recommended_target_cpa_micros"]) -> None: ...
    global___TargetCpaOptInRecommendation = TargetCpaOptInRecommendation

    class KeywordMatchTypeRecommendation(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        recommended_match_type = ... # type: google___ads___googleads___v2___enums___keyword_match_type_pb2___KeywordMatchTypeEnum.KeywordMatchType

        @property
        def keyword(self) -> google___ads___googleads___v2___common___criteria_pb2___KeywordInfo: ...

        def __init__(self,
            *,
            keyword : typing___Optional[google___ads___googleads___v2___common___criteria_pb2___KeywordInfo] = None,
            recommended_match_type : typing___Optional[google___ads___googleads___v2___enums___keyword_match_type_pb2___KeywordMatchTypeEnum.KeywordMatchType] = None,
            ) -> None: ...
        if sys.version_info >= (3,):
            @classmethod
            def FromString(cls, s: builtin___bytes) -> Recommendation.KeywordMatchTypeRecommendation: ...
        else:
            @classmethod
            def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Recommendation.KeywordMatchTypeRecommendation: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def HasField(self, field_name: typing_extensions___Literal[u"keyword",b"keyword"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"keyword",b"keyword",u"recommended_match_type",b"recommended_match_type"]) -> None: ...
    global___KeywordMatchTypeRecommendation = KeywordMatchTypeRecommendation

    class MaximizeConversionsOptInRecommendation(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def recommended_budget_amount_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        def __init__(self,
            *,
            recommended_budget_amount_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            ) -> None: ...
        if sys.version_info >= (3,):
            @classmethod
            def FromString(cls, s: builtin___bytes) -> Recommendation.MaximizeConversionsOptInRecommendation: ...
        else:
            @classmethod
            def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Recommendation.MaximizeConversionsOptInRecommendation: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def HasField(self, field_name: typing_extensions___Literal[u"recommended_budget_amount_micros",b"recommended_budget_amount_micros"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"recommended_budget_amount_micros",b"recommended_budget_amount_micros"]) -> None: ...
    global___MaximizeConversionsOptInRecommendation = MaximizeConversionsOptInRecommendation

    class EnhancedCpcOptInRecommendation(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        def __init__(self,
            ) -> None: ...
        if sys.version_info >= (3,):
            @classmethod
            def FromString(cls, s: builtin___bytes) -> Recommendation.EnhancedCpcOptInRecommendation: ...
        else:
            @classmethod
            def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Recommendation.EnhancedCpcOptInRecommendation: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    global___EnhancedCpcOptInRecommendation = EnhancedCpcOptInRecommendation

    class OptimizeAdRotationRecommendation(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        def __init__(self,
            ) -> None: ...
        if sys.version_info >= (3,):
            @classmethod
            def FromString(cls, s: builtin___bytes) -> Recommendation.OptimizeAdRotationRecommendation: ...
        else:
            @classmethod
            def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Recommendation.OptimizeAdRotationRecommendation: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    global___OptimizeAdRotationRecommendation = OptimizeAdRotationRecommendation

    class CalloutExtensionRecommendation(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def recommended_extensions(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v2___common___extensions_pb2___CalloutFeedItem]: ...

        def __init__(self,
            *,
            recommended_extensions : typing___Optional[typing___Iterable[google___ads___googleads___v2___common___extensions_pb2___CalloutFeedItem]] = None,
            ) -> None: ...
        if sys.version_info >= (3,):
            @classmethod
            def FromString(cls, s: builtin___bytes) -> Recommendation.CalloutExtensionRecommendation: ...
        else:
            @classmethod
            def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Recommendation.CalloutExtensionRecommendation: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"recommended_extensions",b"recommended_extensions"]) -> None: ...
    global___CalloutExtensionRecommendation = CalloutExtensionRecommendation

    class SitelinkExtensionRecommendation(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def recommended_extensions(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v2___common___extensions_pb2___SitelinkFeedItem]: ...

        def __init__(self,
            *,
            recommended_extensions : typing___Optional[typing___Iterable[google___ads___googleads___v2___common___extensions_pb2___SitelinkFeedItem]] = None,
            ) -> None: ...
        if sys.version_info >= (3,):
            @classmethod
            def FromString(cls, s: builtin___bytes) -> Recommendation.SitelinkExtensionRecommendation: ...
        else:
            @classmethod
            def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Recommendation.SitelinkExtensionRecommendation: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"recommended_extensions",b"recommended_extensions"]) -> None: ...
    global___SitelinkExtensionRecommendation = SitelinkExtensionRecommendation

    resource_name = ... # type: typing___Text
    type = ... # type: google___ads___googleads___v2___enums___recommendation_type_pb2___RecommendationTypeEnum.RecommendationType

    @property
    def impact(self) -> global___Recommendation.RecommendationImpact: ...

    @property
    def campaign_budget(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def campaign(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def ad_group(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def dismissed(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def campaign_budget_recommendation(self) -> global___Recommendation.CampaignBudgetRecommendation: ...

    @property
    def keyword_recommendation(self) -> global___Recommendation.KeywordRecommendation: ...

    @property
    def text_ad_recommendation(self) -> global___Recommendation.TextAdRecommendation: ...

    @property
    def target_cpa_opt_in_recommendation(self) -> global___Recommendation.TargetCpaOptInRecommendation: ...

    @property
    def maximize_conversions_opt_in_recommendation(self) -> global___Recommendation.MaximizeConversionsOptInRecommendation: ...

    @property
    def enhanced_cpc_opt_in_recommendation(self) -> global___Recommendation.EnhancedCpcOptInRecommendation: ...

    @property
    def search_partners_opt_in_recommendation(self) -> global___Recommendation.SearchPartnersOptInRecommendation: ...

    @property
    def maximize_clicks_opt_in_recommendation(self) -> global___Recommendation.MaximizeClicksOptInRecommendation: ...

    @property
    def optimize_ad_rotation_recommendation(self) -> global___Recommendation.OptimizeAdRotationRecommendation: ...

    @property
    def callout_extension_recommendation(self) -> global___Recommendation.CalloutExtensionRecommendation: ...

    @property
    def sitelink_extension_recommendation(self) -> global___Recommendation.SitelinkExtensionRecommendation: ...

    @property
    def call_extension_recommendation(self) -> global___Recommendation.CallExtensionRecommendation: ...

    @property
    def keyword_match_type_recommendation(self) -> global___Recommendation.KeywordMatchTypeRecommendation: ...

    @property
    def move_unused_budget_recommendation(self) -> global___Recommendation.MoveUnusedBudgetRecommendation: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        type : typing___Optional[google___ads___googleads___v2___enums___recommendation_type_pb2___RecommendationTypeEnum.RecommendationType] = None,
        impact : typing___Optional[global___Recommendation.RecommendationImpact] = None,
        campaign_budget : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        campaign : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ad_group : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        dismissed : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        campaign_budget_recommendation : typing___Optional[global___Recommendation.CampaignBudgetRecommendation] = None,
        keyword_recommendation : typing___Optional[global___Recommendation.KeywordRecommendation] = None,
        text_ad_recommendation : typing___Optional[global___Recommendation.TextAdRecommendation] = None,
        target_cpa_opt_in_recommendation : typing___Optional[global___Recommendation.TargetCpaOptInRecommendation] = None,
        maximize_conversions_opt_in_recommendation : typing___Optional[global___Recommendation.MaximizeConversionsOptInRecommendation] = None,
        enhanced_cpc_opt_in_recommendation : typing___Optional[global___Recommendation.EnhancedCpcOptInRecommendation] = None,
        search_partners_opt_in_recommendation : typing___Optional[global___Recommendation.SearchPartnersOptInRecommendation] = None,
        maximize_clicks_opt_in_recommendation : typing___Optional[global___Recommendation.MaximizeClicksOptInRecommendation] = None,
        optimize_ad_rotation_recommendation : typing___Optional[global___Recommendation.OptimizeAdRotationRecommendation] = None,
        callout_extension_recommendation : typing___Optional[global___Recommendation.CalloutExtensionRecommendation] = None,
        sitelink_extension_recommendation : typing___Optional[global___Recommendation.SitelinkExtensionRecommendation] = None,
        call_extension_recommendation : typing___Optional[global___Recommendation.CallExtensionRecommendation] = None,
        keyword_match_type_recommendation : typing___Optional[global___Recommendation.KeywordMatchTypeRecommendation] = None,
        move_unused_budget_recommendation : typing___Optional[global___Recommendation.MoveUnusedBudgetRecommendation] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> Recommendation: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Recommendation: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def HasField(self, field_name: typing_extensions___Literal[u"ad_group",b"ad_group",u"call_extension_recommendation",b"call_extension_recommendation",u"callout_extension_recommendation",b"callout_extension_recommendation",u"campaign",b"campaign",u"campaign_budget",b"campaign_budget",u"campaign_budget_recommendation",b"campaign_budget_recommendation",u"dismissed",b"dismissed",u"enhanced_cpc_opt_in_recommendation",b"enhanced_cpc_opt_in_recommendation",u"impact",b"impact",u"keyword_match_type_recommendation",b"keyword_match_type_recommendation",u"keyword_recommendation",b"keyword_recommendation",u"maximize_clicks_opt_in_recommendation",b"maximize_clicks_opt_in_recommendation",u"maximize_conversions_opt_in_recommendation",b"maximize_conversions_opt_in_recommendation",u"move_unused_budget_recommendation",b"move_unused_budget_recommendation",u"optimize_ad_rotation_recommendation",b"optimize_ad_rotation_recommendation",u"recommendation",b"recommendation",u"search_partners_opt_in_recommendation",b"search_partners_opt_in_recommendation",u"sitelink_extension_recommendation",b"sitelink_extension_recommendation",u"target_cpa_opt_in_recommendation",b"target_cpa_opt_in_recommendation",u"text_ad_recommendation",b"text_ad_recommendation"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"ad_group",b"ad_group",u"call_extension_recommendation",b"call_extension_recommendation",u"callout_extension_recommendation",b"callout_extension_recommendation",u"campaign",b"campaign",u"campaign_budget",b"campaign_budget",u"campaign_budget_recommendation",b"campaign_budget_recommendation",u"dismissed",b"dismissed",u"enhanced_cpc_opt_in_recommendation",b"enhanced_cpc_opt_in_recommendation",u"impact",b"impact",u"keyword_match_type_recommendation",b"keyword_match_type_recommendation",u"keyword_recommendation",b"keyword_recommendation",u"maximize_clicks_opt_in_recommendation",b"maximize_clicks_opt_in_recommendation",u"maximize_conversions_opt_in_recommendation",b"maximize_conversions_opt_in_recommendation",u"move_unused_budget_recommendation",b"move_unused_budget_recommendation",u"optimize_ad_rotation_recommendation",b"optimize_ad_rotation_recommendation",u"recommendation",b"recommendation",u"resource_name",b"resource_name",u"search_partners_opt_in_recommendation",b"search_partners_opt_in_recommendation",u"sitelink_extension_recommendation",b"sitelink_extension_recommendation",u"target_cpa_opt_in_recommendation",b"target_cpa_opt_in_recommendation",u"text_ad_recommendation",b"text_ad_recommendation",u"type",b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"recommendation",b"recommendation"]) -> typing_extensions___Literal["campaign_budget_recommendation","keyword_recommendation","text_ad_recommendation","target_cpa_opt_in_recommendation","maximize_conversions_opt_in_recommendation","enhanced_cpc_opt_in_recommendation","search_partners_opt_in_recommendation","maximize_clicks_opt_in_recommendation","optimize_ad_rotation_recommendation","callout_extension_recommendation","sitelink_extension_recommendation","call_extension_recommendation","keyword_match_type_recommendation","move_unused_budget_recommendation"]: ...
global___Recommendation = Recommendation



class ResourceName:
    @classmethod
    def format_composite(cls, *arg: str): str

def get_nested_attr(obj: Any, attr: str, *args: Any) -> Any: ...
def convert_upper_case_to_snake_case(string: str) -> str: ...
def convert_snake_case_to_upper_case(string: str) -> str: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class CampaignCriterionErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class CampaignCriterionError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> CampaignCriterionErrorEnum.CampaignCriterionError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[CampaignCriterionErrorEnum.CampaignCriterionError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, CampaignCriterionErrorEnum.CampaignCriterionError]]: ...
        UNSPECIFIED = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 0)
        UNKNOWN = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 1)
        CONCRETE_TYPE_REQUIRED = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 2)
        INVALID_PLACEMENT_URL = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 3)
        CANNOT_EXCLUDE_CRITERIA_TYPE = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 4)
        CANNOT_SET_STATUS_FOR_CRITERIA_TYPE = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 5)
        CANNOT_SET_STATUS_FOR_EXCLUDED_CRITERIA = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 6)
        CANNOT_TARGET_AND_EXCLUDE = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 7)
        TOO_MANY_OPERATIONS = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 8)
        OPERATOR_NOT_SUPPORTED_FOR_CRITERION_TYPE = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 9)
        SHOPPING_CAMPAIGN_SALES_COUNTRY_NOT_SUPPORTED_FOR_SALES_CHANNEL = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 10)
        CANNOT_ADD_EXISTING_FIELD = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 11)
        CANNOT_UPDATE_NEGATIVE_CRITERION = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 12)
    UNSPECIFIED = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 0)
    UNKNOWN = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 1)
    CONCRETE_TYPE_REQUIRED = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 2)
    INVALID_PLACEMENT_URL = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 3)
    CANNOT_EXCLUDE_CRITERIA_TYPE = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 4)
    CANNOT_SET_STATUS_FOR_CRITERIA_TYPE = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 5)
    CANNOT_SET_STATUS_FOR_EXCLUDED_CRITERIA = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 6)
    CANNOT_TARGET_AND_EXCLUDE = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 7)
    TOO_MANY_OPERATIONS = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 8)
    OPERATOR_NOT_SUPPORTED_FOR_CRITERION_TYPE = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 9)
    SHOPPING_CAMPAIGN_SALES_COUNTRY_NOT_SUPPORTED_FOR_SALES_CHANNEL = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 10)
    CANNOT_ADD_EXISTING_FIELD = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 11)
    CANNOT_UPDATE_NEGATIVE_CRITERION = typing___cast(CampaignCriterionErrorEnum.CampaignCriterionError, 12)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CampaignCriterionErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# Stubs for google.ads.google_ads.v1.services.transports.customer_feed_service_grpc_transport (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional

class CustomerFeedServiceGrpcTransport:
    def __init__(self, channel: Optional[Any] = ..., credentials: Optional[Any] = ..., address: str = ...) -> None: ...
    @classmethod
    def create_channel(cls, address: str = ..., credentials: Optional[Any] = ..., **kwargs: Any): ...
    @property
    def channel(self): ...
    @property
    def get_customer_feed(self): ...
    @property
    def mutate_customer_feeds(self): ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class AttributionModelEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class AttributionModel(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> AttributionModelEnum.AttributionModel: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[AttributionModelEnum.AttributionModel]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, AttributionModelEnum.AttributionModel]]: ...
        UNSPECIFIED = typing___cast(AttributionModelEnum.AttributionModel, 0)
        UNKNOWN = typing___cast(AttributionModelEnum.AttributionModel, 1)
        EXTERNAL = typing___cast(AttributionModelEnum.AttributionModel, 100)
        GOOGLE_ADS_LAST_CLICK = typing___cast(AttributionModelEnum.AttributionModel, 101)
        GOOGLE_SEARCH_ATTRIBUTION_FIRST_CLICK = typing___cast(AttributionModelEnum.AttributionModel, 102)
        GOOGLE_SEARCH_ATTRIBUTION_LINEAR = typing___cast(AttributionModelEnum.AttributionModel, 103)
        GOOGLE_SEARCH_ATTRIBUTION_TIME_DECAY = typing___cast(AttributionModelEnum.AttributionModel, 104)
        GOOGLE_SEARCH_ATTRIBUTION_POSITION_BASED = typing___cast(AttributionModelEnum.AttributionModel, 105)
        GOOGLE_SEARCH_ATTRIBUTION_DATA_DRIVEN = typing___cast(AttributionModelEnum.AttributionModel, 106)
    UNSPECIFIED = typing___cast(AttributionModelEnum.AttributionModel, 0)
    UNKNOWN = typing___cast(AttributionModelEnum.AttributionModel, 1)
    EXTERNAL = typing___cast(AttributionModelEnum.AttributionModel, 100)
    GOOGLE_ADS_LAST_CLICK = typing___cast(AttributionModelEnum.AttributionModel, 101)
    GOOGLE_SEARCH_ATTRIBUTION_FIRST_CLICK = typing___cast(AttributionModelEnum.AttributionModel, 102)
    GOOGLE_SEARCH_ATTRIBUTION_LINEAR = typing___cast(AttributionModelEnum.AttributionModel, 103)
    GOOGLE_SEARCH_ATTRIBUTION_TIME_DECAY = typing___cast(AttributionModelEnum.AttributionModel, 104)
    GOOGLE_SEARCH_ATTRIBUTION_POSITION_BASED = typing___cast(AttributionModelEnum.AttributionModel, 105)
    GOOGLE_SEARCH_ATTRIBUTION_DATA_DRIVEN = typing___cast(AttributionModelEnum.AttributionModel, 106)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AttributionModelEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class AdGroupCriterionErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class AdGroupCriterionError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> AdGroupCriterionErrorEnum.AdGroupCriterionError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[AdGroupCriterionErrorEnum.AdGroupCriterionError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, AdGroupCriterionErrorEnum.AdGroupCriterionError]]: ...
        UNSPECIFIED = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 0)
        UNKNOWN = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 1)
        AD_GROUP_CRITERION_LABEL_DOES_NOT_EXIST = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 2)
        AD_GROUP_CRITERION_LABEL_ALREADY_EXISTS = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 3)
        CANNOT_ADD_LABEL_TO_NEGATIVE_CRITERION = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 4)
        TOO_MANY_OPERATIONS = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 5)
        CANT_UPDATE_NEGATIVE = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 6)
        CONCRETE_TYPE_REQUIRED = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 7)
        BID_INCOMPATIBLE_WITH_ADGROUP = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 8)
        CANNOT_TARGET_AND_EXCLUDE = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 9)
        ILLEGAL_URL = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 10)
        INVALID_KEYWORD_TEXT = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 11)
        INVALID_DESTINATION_URL = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 12)
        MISSING_DESTINATION_URL_TAG = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 13)
        KEYWORD_LEVEL_BID_NOT_SUPPORTED_FOR_MANUALCPM = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 14)
        INVALID_USER_STATUS = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 15)
        CANNOT_ADD_CRITERIA_TYPE = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 16)
        CANNOT_EXCLUDE_CRITERIA_TYPE = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 17)
        CAMPAIGN_TYPE_NOT_COMPATIBLE_WITH_PARTIAL_FAILURE = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 27)
        OPERATIONS_FOR_TOO_MANY_SHOPPING_ADGROUPS = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 28)
        CANNOT_MODIFY_URL_FIELDS_WITH_DUPLICATE_ELEMENTS = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 29)
        CANNOT_SET_WITHOUT_FINAL_URLS = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 30)
        CANNOT_CLEAR_FINAL_URLS_IF_FINAL_MOBILE_URLS_EXIST = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 31)
        CANNOT_CLEAR_FINAL_URLS_IF_FINAL_APP_URLS_EXIST = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 32)
        CANNOT_CLEAR_FINAL_URLS_IF_TRACKING_URL_TEMPLATE_EXISTS = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 33)
        CANNOT_CLEAR_FINAL_URLS_IF_URL_CUSTOM_PARAMETERS_EXIST = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 34)
        CANNOT_SET_BOTH_DESTINATION_URL_AND_FINAL_URLS = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 35)
        CANNOT_SET_BOTH_DESTINATION_URL_AND_TRACKING_URL_TEMPLATE = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 36)
        FINAL_URLS_NOT_SUPPORTED_FOR_CRITERION_TYPE = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 37)
        FINAL_MOBILE_URLS_NOT_SUPPORTED_FOR_CRITERION_TYPE = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 38)
        INVALID_LISTING_GROUP_HIERARCHY = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 39)
        LISTING_GROUP_UNIT_CANNOT_HAVE_CHILDREN = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 40)
        LISTING_GROUP_SUBDIVISION_REQUIRES_OTHERS_CASE = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 41)
        LISTING_GROUP_REQUIRES_SAME_DIMENSION_TYPE_AS_SIBLINGS = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 42)
        LISTING_GROUP_ALREADY_EXISTS = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 43)
        LISTING_GROUP_DOES_NOT_EXIST = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 44)
        LISTING_GROUP_CANNOT_BE_REMOVED = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 45)
        INVALID_LISTING_GROUP_TYPE = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 46)
        LISTING_GROUP_ADD_MAY_ONLY_USE_TEMP_ID = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 47)
    UNSPECIFIED = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 0)
    UNKNOWN = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 1)
    AD_GROUP_CRITERION_LABEL_DOES_NOT_EXIST = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 2)
    AD_GROUP_CRITERION_LABEL_ALREADY_EXISTS = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 3)
    CANNOT_ADD_LABEL_TO_NEGATIVE_CRITERION = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 4)
    TOO_MANY_OPERATIONS = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 5)
    CANT_UPDATE_NEGATIVE = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 6)
    CONCRETE_TYPE_REQUIRED = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 7)
    BID_INCOMPATIBLE_WITH_ADGROUP = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 8)
    CANNOT_TARGET_AND_EXCLUDE = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 9)
    ILLEGAL_URL = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 10)
    INVALID_KEYWORD_TEXT = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 11)
    INVALID_DESTINATION_URL = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 12)
    MISSING_DESTINATION_URL_TAG = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 13)
    KEYWORD_LEVEL_BID_NOT_SUPPORTED_FOR_MANUALCPM = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 14)
    INVALID_USER_STATUS = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 15)
    CANNOT_ADD_CRITERIA_TYPE = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 16)
    CANNOT_EXCLUDE_CRITERIA_TYPE = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 17)
    CAMPAIGN_TYPE_NOT_COMPATIBLE_WITH_PARTIAL_FAILURE = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 27)
    OPERATIONS_FOR_TOO_MANY_SHOPPING_ADGROUPS = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 28)
    CANNOT_MODIFY_URL_FIELDS_WITH_DUPLICATE_ELEMENTS = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 29)
    CANNOT_SET_WITHOUT_FINAL_URLS = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 30)
    CANNOT_CLEAR_FINAL_URLS_IF_FINAL_MOBILE_URLS_EXIST = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 31)
    CANNOT_CLEAR_FINAL_URLS_IF_FINAL_APP_URLS_EXIST = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 32)
    CANNOT_CLEAR_FINAL_URLS_IF_TRACKING_URL_TEMPLATE_EXISTS = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 33)
    CANNOT_CLEAR_FINAL_URLS_IF_URL_CUSTOM_PARAMETERS_EXIST = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 34)
    CANNOT_SET_BOTH_DESTINATION_URL_AND_FINAL_URLS = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 35)
    CANNOT_SET_BOTH_DESTINATION_URL_AND_TRACKING_URL_TEMPLATE = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 36)
    FINAL_URLS_NOT_SUPPORTED_FOR_CRITERION_TYPE = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 37)
    FINAL_MOBILE_URLS_NOT_SUPPORTED_FOR_CRITERION_TYPE = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 38)
    INVALID_LISTING_GROUP_HIERARCHY = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 39)
    LISTING_GROUP_UNIT_CANNOT_HAVE_CHILDREN = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 40)
    LISTING_GROUP_SUBDIVISION_REQUIRES_OTHERS_CASE = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 41)
    LISTING_GROUP_REQUIRES_SAME_DIMENSION_TYPE_AS_SIBLINGS = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 42)
    LISTING_GROUP_ALREADY_EXISTS = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 43)
    LISTING_GROUP_DOES_NOT_EXIST = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 44)
    LISTING_GROUP_CANNOT_BE_REMOVED = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 45)
    INVALID_LISTING_GROUP_TYPE = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 46)
    LISTING_GROUP_ADD_MAY_ONLY_USE_TEMP_ID = typing___cast(AdGroupCriterionErrorEnum.AdGroupCriterionError, 47)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AdGroupCriterionErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.enums.change_status_operation_pb2 import (
    ChangeStatusOperationEnum as google___ads___googleads___v2___enums___change_status_operation_pb2___ChangeStatusOperationEnum,
)

from google.ads.google_ads.v2.proto.enums.change_status_resource_type_pb2 import (
    ChangeStatusResourceTypeEnum as google___ads___googleads___v2___enums___change_status_resource_type_pb2___ChangeStatusResourceTypeEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class ChangeStatus(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    resource_type = ... # type: google___ads___googleads___v2___enums___change_status_resource_type_pb2___ChangeStatusResourceTypeEnum.ChangeStatusResourceType
    resource_status = ... # type: google___ads___googleads___v2___enums___change_status_operation_pb2___ChangeStatusOperationEnum.ChangeStatusOperation

    @property
    def last_change_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def campaign(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def ad_group(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def ad_group_ad(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def ad_group_criterion(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def campaign_criterion(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def feed(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def feed_item(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def ad_group_feed(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def campaign_feed(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def ad_group_bid_modifier(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        last_change_date_time : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        resource_type : typing___Optional[google___ads___googleads___v2___enums___change_status_resource_type_pb2___ChangeStatusResourceTypeEnum.ChangeStatusResourceType] = None,
        campaign : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ad_group : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        resource_status : typing___Optional[google___ads___googleads___v2___enums___change_status_operation_pb2___ChangeStatusOperationEnum.ChangeStatusOperation] = None,
        ad_group_ad : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ad_group_criterion : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        campaign_criterion : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        feed : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        feed_item : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ad_group_feed : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        campaign_feed : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ad_group_bid_modifier : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ChangeStatus: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"ad_group",u"ad_group_ad",u"ad_group_bid_modifier",u"ad_group_criterion",u"ad_group_feed",u"campaign",u"campaign_criterion",u"campaign_feed",u"feed",u"feed_item",u"last_change_date_time"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group",u"ad_group_ad",u"ad_group_bid_modifier",u"ad_group_criterion",u"ad_group_feed",u"campaign",u"campaign_criterion",u"campaign_feed",u"feed",u"feed_item",u"last_change_date_time",u"resource_name",u"resource_status",u"resource_type"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"ad_group",b"ad_group",u"ad_group_ad",b"ad_group_ad",u"ad_group_bid_modifier",b"ad_group_bid_modifier",u"ad_group_criterion",b"ad_group_criterion",u"ad_group_feed",b"ad_group_feed",u"campaign",b"campaign",u"campaign_criterion",b"campaign_criterion",u"campaign_feed",b"campaign_feed",u"feed",b"feed",u"feed_item",b"feed_item",u"last_change_date_time",b"last_change_date_time"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group",b"ad_group",u"ad_group_ad",b"ad_group_ad",u"ad_group_bid_modifier",b"ad_group_bid_modifier",u"ad_group_criterion",b"ad_group_criterion",u"ad_group_feed",b"ad_group_feed",u"campaign",b"campaign",u"campaign_criterion",b"campaign_criterion",u"campaign_feed",b"campaign_feed",u"feed",b"feed",u"feed_item",b"feed_item",u"last_change_date_time",b"last_change_date_time",u"resource_name",b"resource_name",u"resource_status",b"resource_status",u"resource_type",b"resource_type"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.common.bidding_pb2 import (
    Commission as google___ads___googleads___v2___common___bidding_pb2___Commission,
    ManualCpc as google___ads___googleads___v2___common___bidding_pb2___ManualCpc,
    ManualCpm as google___ads___googleads___v2___common___bidding_pb2___ManualCpm,
    ManualCpv as google___ads___googleads___v2___common___bidding_pb2___ManualCpv,
    MaximizeConversionValue as google___ads___googleads___v2___common___bidding_pb2___MaximizeConversionValue,
    MaximizeConversions as google___ads___googleads___v2___common___bidding_pb2___MaximizeConversions,
    PercentCpc as google___ads___googleads___v2___common___bidding_pb2___PercentCpc,
    TargetCpa as google___ads___googleads___v2___common___bidding_pb2___TargetCpa,
    TargetCpm as google___ads___googleads___v2___common___bidding_pb2___TargetCpm,
    TargetImpressionShare as google___ads___googleads___v2___common___bidding_pb2___TargetImpressionShare,
    TargetRoas as google___ads___googleads___v2___common___bidding_pb2___TargetRoas,
    TargetSpend as google___ads___googleads___v2___common___bidding_pb2___TargetSpend,
)

from google.ads.google_ads.v2.proto.common.custom_parameter_pb2 import (
    CustomParameter as google___ads___googleads___v2___common___custom_parameter_pb2___CustomParameter,
)

from google.ads.google_ads.v2.proto.common.frequency_cap_pb2 import (
    FrequencyCapEntry as google___ads___googleads___v2___common___frequency_cap_pb2___FrequencyCapEntry,
)

from google.ads.google_ads.v2.proto.common.real_time_bidding_setting_pb2 import (
    RealTimeBiddingSetting as google___ads___googleads___v2___common___real_time_bidding_setting_pb2___RealTimeBiddingSetting,
)

from google.ads.google_ads.v2.proto.common.targeting_setting_pb2 import (
    TargetingSetting as google___ads___googleads___v2___common___targeting_setting_pb2___TargetingSetting,
)

from google.ads.google_ads.v2.proto.enums.ad_serving_optimization_status_pb2 import (
    AdServingOptimizationStatusEnum as google___ads___googleads___v2___enums___ad_serving_optimization_status_pb2___AdServingOptimizationStatusEnum,
)

from google.ads.google_ads.v2.proto.enums.advertising_channel_sub_type_pb2 import (
    AdvertisingChannelSubTypeEnum as google___ads___googleads___v2___enums___advertising_channel_sub_type_pb2___AdvertisingChannelSubTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.advertising_channel_type_pb2 import (
    AdvertisingChannelTypeEnum as google___ads___googleads___v2___enums___advertising_channel_type_pb2___AdvertisingChannelTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.app_campaign_app_store_pb2 import (
    AppCampaignAppStoreEnum as google___ads___googleads___v2___enums___app_campaign_app_store_pb2___AppCampaignAppStoreEnum,
)

from google.ads.google_ads.v2.proto.enums.app_campaign_bidding_strategy_goal_type_pb2 import (
    AppCampaignBiddingStrategyGoalTypeEnum as google___ads___googleads___v2___enums___app_campaign_bidding_strategy_goal_type_pb2___AppCampaignBiddingStrategyGoalTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.bidding_strategy_type_pb2 import (
    BiddingStrategyTypeEnum as google___ads___googleads___v2___enums___bidding_strategy_type_pb2___BiddingStrategyTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.brand_safety_suitability_pb2 import (
    BrandSafetySuitabilityEnum as google___ads___googleads___v2___enums___brand_safety_suitability_pb2___BrandSafetySuitabilityEnum,
)

from google.ads.google_ads.v2.proto.enums.campaign_experiment_type_pb2 import (
    CampaignExperimentTypeEnum as google___ads___googleads___v2___enums___campaign_experiment_type_pb2___CampaignExperimentTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.campaign_serving_status_pb2 import (
    CampaignServingStatusEnum as google___ads___googleads___v2___enums___campaign_serving_status_pb2___CampaignServingStatusEnum,
)

from google.ads.google_ads.v2.proto.enums.campaign_status_pb2 import (
    CampaignStatusEnum as google___ads___googleads___v2___enums___campaign_status_pb2___CampaignStatusEnum,
)

from google.ads.google_ads.v2.proto.enums.negative_geo_target_type_pb2 import (
    NegativeGeoTargetTypeEnum as google___ads___googleads___v2___enums___negative_geo_target_type_pb2___NegativeGeoTargetTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.payment_mode_pb2 import (
    PaymentModeEnum as google___ads___googleads___v2___enums___payment_mode_pb2___PaymentModeEnum,
)

from google.ads.google_ads.v2.proto.enums.positive_geo_target_type_pb2 import (
    PositiveGeoTargetTypeEnum as google___ads___googleads___v2___enums___positive_geo_target_type_pb2___PositiveGeoTargetTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.vanity_pharma_display_url_mode_pb2 import (
    VanityPharmaDisplayUrlModeEnum as google___ads___googleads___v2___enums___vanity_pharma_display_url_mode_pb2___VanityPharmaDisplayUrlModeEnum,
)

from google.ads.google_ads.v2.proto.enums.vanity_pharma_text_pb2 import (
    VanityPharmaTextEnum as google___ads___googleads___v2___enums___vanity_pharma_text_pb2___VanityPharmaTextEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    Int32Value as google___protobuf___wrappers_pb2___Int32Value,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
    Union as typing___Union,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int
if sys.version_info < (3,):
    builtin___buffer = buffer
    builtin___unicode = unicode


class Campaign(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class NetworkSettings(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def target_google_search(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

        @property
        def target_search_network(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

        @property
        def target_content_network(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

        @property
        def target_partner_search_network(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

        def __init__(self,
            *,
            target_google_search : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
            target_search_network : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
            target_content_network : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
            target_partner_search_network : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
            ) -> None: ...
        if sys.version_info >= (3,):
            @classmethod
            def FromString(cls, s: builtin___bytes) -> Campaign.NetworkSettings: ...
        else:
            @classmethod
            def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Campaign.NetworkSettings: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def HasField(self, field_name: typing_extensions___Literal[u"target_content_network",b"target_content_network",u"target_google_search",b"target_google_search",u"target_partner_search_network",b"target_partner_search_network",u"target_search_network",b"target_search_network"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"target_content_network",b"target_content_network",u"target_google_search",b"target_google_search",u"target_partner_search_network",b"target_partner_search_network",u"target_search_network",b"target_search_network"]) -> None: ...
    global___NetworkSettings = NetworkSettings

    class HotelSettingInfo(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def hotel_center_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        def __init__(self,
            *,
            hotel_center_id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            ) -> None: ...
        if sys.version_info >= (3,):
            @classmethod
            def FromString(cls, s: builtin___bytes) -> Campaign.HotelSettingInfo: ...
        else:
            @classmethod
            def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Campaign.HotelSettingInfo: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def HasField(self, field_name: typing_extensions___Literal[u"hotel_center_id",b"hotel_center_id"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"hotel_center_id",b"hotel_center_id"]) -> None: ...
    global___HotelSettingInfo = HotelSettingInfo

    class VanityPharma(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        vanity_pharma_display_url_mode = ... # type: google___ads___googleads___v2___enums___vanity_pharma_display_url_mode_pb2___VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlMode
        vanity_pharma_text = ... # type: google___ads___googleads___v2___enums___vanity_pharma_text_pb2___VanityPharmaTextEnum.VanityPharmaText

        def __init__(self,
            *,
            vanity_pharma_display_url_mode : typing___Optional[google___ads___googleads___v2___enums___vanity_pharma_display_url_mode_pb2___VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlMode] = None,
            vanity_pharma_text : typing___Optional[google___ads___googleads___v2___enums___vanity_pharma_text_pb2___VanityPharmaTextEnum.VanityPharmaText] = None,
            ) -> None: ...
        if sys.version_info >= (3,):
            @classmethod
            def FromString(cls, s: builtin___bytes) -> Campaign.VanityPharma: ...
        else:
            @classmethod
            def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Campaign.VanityPharma: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"vanity_pharma_display_url_mode",b"vanity_pharma_display_url_mode",u"vanity_pharma_text",b"vanity_pharma_text"]) -> None: ...
    global___VanityPharma = VanityPharma

    class DynamicSearchAdsSetting(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def domain_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def language_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def use_supplied_urls_only(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

        @property
        def feeds(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

        def __init__(self,
            *,
            domain_name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            language_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            use_supplied_urls_only : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
            feeds : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
            ) -> None: ...
        if sys.version_info >= (3,):
            @classmethod
            def FromString(cls, s: builtin___bytes) -> Campaign.DynamicSearchAdsSetting: ...
        else:
            @classmethod
            def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Campaign.DynamicSearchAdsSetting: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def HasField(self, field_name: typing_extensions___Literal[u"domain_name",b"domain_name",u"language_code",b"language_code",u"use_supplied_urls_only",b"use_supplied_urls_only"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"domain_name",b"domain_name",u"feeds",b"feeds",u"language_code",b"language_code",u"use_supplied_urls_only",b"use_supplied_urls_only"]) -> None: ...
    global___DynamicSearchAdsSetting = DynamicSearchAdsSetting

    class SelectiveOptimization(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def conversion_actions(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

        def __init__(self,
            *,
            conversion_actions : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
            ) -> None: ...
        if sys.version_info >= (3,):
            @classmethod
            def FromString(cls, s: builtin___bytes) -> Campaign.SelectiveOptimization: ...
        else:
            @classmethod
            def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Campaign.SelectiveOptimization: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"conversion_actions",b"conversion_actions"]) -> None: ...
    global___SelectiveOptimization = SelectiveOptimization

    class ShoppingSetting(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def merchant_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        @property
        def sales_country(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def campaign_priority(self) -> google___protobuf___wrappers_pb2___Int32Value: ...

        @property
        def enable_local(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

        def __init__(self,
            *,
            merchant_id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            sales_country : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            campaign_priority : typing___Optional[google___protobuf___wrappers_pb2___Int32Value] = None,
            enable_local : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
            ) -> None: ...
        if sys.version_info >= (3,):
            @classmethod
            def FromString(cls, s: builtin___bytes) -> Campaign.ShoppingSetting: ...
        else:
            @classmethod
            def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Campaign.ShoppingSetting: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def HasField(self, field_name: typing_extensions___Literal[u"campaign_priority",b"campaign_priority",u"enable_local",b"enable_local",u"merchant_id",b"merchant_id",u"sales_country",b"sales_country"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"campaign_priority",b"campaign_priority",u"enable_local",b"enable_local",u"merchant_id",b"merchant_id",u"sales_country",b"sales_country"]) -> None: ...
    global___ShoppingSetting = ShoppingSetting

    class TrackingSetting(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def tracking_url(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        def __init__(self,
            *,
            tracking_url : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            ) -> None: ...
        if sys.version_info >= (3,):
            @classmethod
            def FromString(cls, s: builtin___bytes) -> Campaign.TrackingSetting: ...
        else:
            @classmethod
            def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Campaign.TrackingSetting: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def HasField(self, field_name: typing_extensions___Literal[u"tracking_url",b"tracking_url"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"tracking_url",b"tracking_url"]) -> None: ...
    global___TrackingSetting = TrackingSetting

    class AppCampaignSetting(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        bidding_strategy_goal_type = ... # type: google___ads___googleads___v2___enums___app_campaign_bidding_strategy_goal_type_pb2___AppCampaignBiddingStrategyGoalTypeEnum.AppCampaignBiddingStrategyGoalType
        app_store = ... # type: google___ads___googleads___v2___enums___app_campaign_app_store_pb2___AppCampaignAppStoreEnum.AppCampaignAppStore

        @property
        def app_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        def __init__(self,
            *,
            bidding_strategy_goal_type : typing___Optional[google___ads___googleads___v2___enums___app_campaign_bidding_strategy_goal_type_pb2___AppCampaignBiddingStrategyGoalTypeEnum.AppCampaignBiddingStrategyGoalType] = None,
            app_id : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            app_store : typing___Optional[google___ads___googleads___v2___enums___app_campaign_app_store_pb2___AppCampaignAppStoreEnum.AppCampaignAppStore] = None,
            ) -> None: ...
        if sys.version_info >= (3,):
            @classmethod
            def FromString(cls, s: builtin___bytes) -> Campaign.AppCampaignSetting: ...
        else:
            @classmethod
            def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Campaign.AppCampaignSetting: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def HasField(self, field_name: typing_extensions___Literal[u"app_id",b"app_id"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"app_id",b"app_id",u"app_store",b"app_store",u"bidding_strategy_goal_type",b"bidding_strategy_goal_type"]) -> None: ...
    global___AppCampaignSetting = AppCampaignSetting

    class GeoTargetTypeSetting(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        positive_geo_target_type = ... # type: google___ads___googleads___v2___enums___positive_geo_target_type_pb2___PositiveGeoTargetTypeEnum.PositiveGeoTargetType
        negative_geo_target_type = ... # type: google___ads___googleads___v2___enums___negative_geo_target_type_pb2___NegativeGeoTargetTypeEnum.NegativeGeoTargetType

        def __init__(self,
            *,
            positive_geo_target_type : typing___Optional[google___ads___googleads___v2___enums___positive_geo_target_type_pb2___PositiveGeoTargetTypeEnum.PositiveGeoTargetType] = None,
            negative_geo_target_type : typing___Optional[google___ads___googleads___v2___enums___negative_geo_target_type_pb2___NegativeGeoTargetTypeEnum.NegativeGeoTargetType] = None,
            ) -> None: ...
        if sys.version_info >= (3,):
            @classmethod
            def FromString(cls, s: builtin___bytes) -> Campaign.GeoTargetTypeSetting: ...
        else:
            @classmethod
            def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Campaign.GeoTargetTypeSetting: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"negative_geo_target_type",b"negative_geo_target_type",u"positive_geo_target_type",b"positive_geo_target_type"]) -> None: ...
    global___GeoTargetTypeSetting = GeoTargetTypeSetting

    resource_name = ... # type: typing___Text
    status = ... # type: google___ads___googleads___v2___enums___campaign_status_pb2___CampaignStatusEnum.CampaignStatus
    serving_status = ... # type: google___ads___googleads___v2___enums___campaign_serving_status_pb2___CampaignServingStatusEnum.CampaignServingStatus
    ad_serving_optimization_status = ... # type: google___ads___googleads___v2___enums___ad_serving_optimization_status_pb2___AdServingOptimizationStatusEnum.AdServingOptimizationStatus
    advertising_channel_type = ... # type: google___ads___googleads___v2___enums___advertising_channel_type_pb2___AdvertisingChannelTypeEnum.AdvertisingChannelType
    advertising_channel_sub_type = ... # type: google___ads___googleads___v2___enums___advertising_channel_sub_type_pb2___AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType
    experiment_type = ... # type: google___ads___googleads___v2___enums___campaign_experiment_type_pb2___CampaignExperimentTypeEnum.CampaignExperimentType
    bidding_strategy_type = ... # type: google___ads___googleads___v2___enums___bidding_strategy_type_pb2___BiddingStrategyTypeEnum.BiddingStrategyType
    video_brand_safety_suitability = ... # type: google___ads___googleads___v2___enums___brand_safety_suitability_pb2___BrandSafetySuitabilityEnum.BrandSafetySuitability
    payment_mode = ... # type: google___ads___googleads___v2___enums___payment_mode_pb2___PaymentModeEnum.PaymentMode

    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def tracking_url_template(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def url_custom_parameters(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v2___common___custom_parameter_pb2___CustomParameter]: ...

    @property
    def real_time_bidding_setting(self) -> google___ads___googleads___v2___common___real_time_bidding_setting_pb2___RealTimeBiddingSetting: ...

    @property
    def network_settings(self) -> global___Campaign.NetworkSettings: ...

    @property
    def hotel_setting(self) -> global___Campaign.HotelSettingInfo: ...

    @property
    def dynamic_search_ads_setting(self) -> global___Campaign.DynamicSearchAdsSetting: ...

    @property
    def shopping_setting(self) -> global___Campaign.ShoppingSetting: ...

    @property
    def targeting_setting(self) -> google___ads___googleads___v2___common___targeting_setting_pb2___TargetingSetting: ...

    @property
    def geo_target_type_setting(self) -> global___Campaign.GeoTargetTypeSetting: ...

    @property
    def app_campaign_setting(self) -> global___Campaign.AppCampaignSetting: ...

    @property
    def labels(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

    @property
    def base_campaign(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def campaign_budget(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def start_date(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def end_date(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def final_url_suffix(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def frequency_caps(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v2___common___frequency_cap_pb2___FrequencyCapEntry]: ...

    @property
    def vanity_pharma(self) -> global___Campaign.VanityPharma: ...

    @property
    def selective_optimization(self) -> global___Campaign.SelectiveOptimization: ...

    @property
    def tracking_setting(self) -> global___Campaign.TrackingSetting: ...

    @property
    def bidding_strategy(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def commission(self) -> google___ads___googleads___v2___common___bidding_pb2___Commission: ...

    @property
    def manual_cpc(self) -> google___ads___googleads___v2___common___bidding_pb2___ManualCpc: ...

    @property
    def manual_cpm(self) -> google___ads___googleads___v2___common___bidding_pb2___ManualCpm: ...

    @property
    def manual_cpv(self) -> google___ads___googleads___v2___common___bidding_pb2___ManualCpv: ...

    @property
    def maximize_conversions(self) -> google___ads___googleads___v2___common___bidding_pb2___MaximizeConversions: ...

    @property
    def maximize_conversion_value(self) -> google___ads___googleads___v2___common___bidding_pb2___MaximizeConversionValue: ...

    @property
    def target_cpa(self) -> google___ads___googleads___v2___common___bidding_pb2___TargetCpa: ...

    @property
    def target_impression_share(self) -> google___ads___googleads___v2___common___bidding_pb2___TargetImpressionShare: ...

    @property
    def target_roas(self) -> google___ads___googleads___v2___common___bidding_pb2___TargetRoas: ...

    @property
    def target_spend(self) -> google___ads___googleads___v2___common___bidding_pb2___TargetSpend: ...

    @property
    def percent_cpc(self) -> google___ads___googleads___v2___common___bidding_pb2___PercentCpc: ...

    @property
    def target_cpm(self) -> google___ads___googleads___v2___common___bidding_pb2___TargetCpm: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        status : typing___Optional[google___ads___googleads___v2___enums___campaign_status_pb2___CampaignStatusEnum.CampaignStatus] = None,
        serving_status : typing___Optional[google___ads___googleads___v2___enums___campaign_serving_status_pb2___CampaignServingStatusEnum.CampaignServingStatus] = None,
        ad_serving_optimization_status : typing___Optional[google___ads___googleads___v2___enums___ad_serving_optimization_status_pb2___AdServingOptimizationStatusEnum.AdServingOptimizationStatus] = None,
        advertising_channel_type : typing___Optional[google___ads___googleads___v2___enums___advertising_channel_type_pb2___AdvertisingChannelTypeEnum.AdvertisingChannelType] = None,
        advertising_channel_sub_type : typing___Optional[google___ads___googleads___v2___enums___advertising_channel_sub_type_pb2___AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType] = None,
        tracking_url_template : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        url_custom_parameters : typing___Optional[typing___Iterable[google___ads___googleads___v2___common___custom_parameter_pb2___CustomParameter]] = None,
        real_time_bidding_setting : typing___Optional[google___ads___googleads___v2___common___real_time_bidding_setting_pb2___RealTimeBiddingSetting] = None,
        network_settings : typing___Optional[global___Campaign.NetworkSettings] = None,
        hotel_setting : typing___Optional[global___Campaign.HotelSettingInfo] = None,
        dynamic_search_ads_setting : typing___Optional[global___Campaign.DynamicSearchAdsSetting] = None,
        shopping_setting : typing___Optional[global___Campaign.ShoppingSetting] = None,
        targeting_setting : typing___Optional[google___ads___googleads___v2___common___targeting_setting_pb2___TargetingSetting] = None,
        geo_target_type_setting : typing___Optional[global___Campaign.GeoTargetTypeSetting] = None,
        app_campaign_setting : typing___Optional[global___Campaign.AppCampaignSetting] = None,
        labels : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
        experiment_type : typing___Optional[google___ads___googleads___v2___enums___campaign_experiment_type_pb2___CampaignExperimentTypeEnum.CampaignExperimentType] = None,
        base_campaign : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        campaign_budget : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        bidding_strategy_type : typing___Optional[google___ads___googleads___v2___enums___bidding_strategy_type_pb2___BiddingStrategyTypeEnum.BiddingStrategyType] = None,
        start_date : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        end_date : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        final_url_suffix : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        frequency_caps : typing___Optional[typing___Iterable[google___ads___googleads___v2___common___frequency_cap_pb2___FrequencyCapEntry]] = None,
        video_brand_safety_suitability : typing___Optional[google___ads___googleads___v2___enums___brand_safety_suitability_pb2___BrandSafetySuitabilityEnum.BrandSafetySuitability] = None,
        vanity_pharma : typing___Optional[global___Campaign.VanityPharma] = None,
        selective_optimization : typing___Optional[global___Campaign.SelectiveOptimization] = None,
        tracking_setting : typing___Optional[global___Campaign.TrackingSetting] = None,
        payment_mode : typing___Optional[google___ads___googleads___v2___enums___payment_mode_pb2___PaymentModeEnum.PaymentMode] = None,
        bidding_strategy : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        commission : typing___Optional[google___ads___googleads___v2___common___bidding_pb2___Commission] = None,
        manual_cpc : typing___Optional[google___ads___googleads___v2___common___bidding_pb2___ManualCpc] = None,
        manual_cpm : typing___Optional[google___ads___googleads___v2___common___bidding_pb2___ManualCpm] = None,
        manual_cpv : typing___Optional[google___ads___googleads___v2___common___bidding_pb2___ManualCpv] = None,
        maximize_conversions : typing___Optional[google___ads___googleads___v2___common___bidding_pb2___MaximizeConversions] = None,
        maximize_conversion_value : typing___Optional[google___ads___googleads___v2___common___bidding_pb2___MaximizeConversionValue] = None,
        target_cpa : typing___Optional[google___ads___googleads___v2___common___bidding_pb2___TargetCpa] = None,
        target_impression_share : typing___Optional[google___ads___googleads___v2___common___bidding_pb2___TargetImpressionShare] = None,
        target_roas : typing___Optional[google___ads___googleads___v2___common___bidding_pb2___TargetRoas] = None,
        target_spend : typing___Optional[google___ads___googleads___v2___common___bidding_pb2___TargetSpend] = None,
        percent_cpc : typing___Optional[google___ads___googleads___v2___common___bidding_pb2___PercentCpc] = None,
        target_cpm : typing___Optional[google___ads___googleads___v2___common___bidding_pb2___TargetCpm] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> Campaign: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Campaign: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def HasField(self, field_name: typing_extensions___Literal[u"app_campaign_setting",b"app_campaign_setting",u"base_campaign",b"base_campaign",u"bidding_strategy",b"bidding_strategy",u"campaign_bidding_strategy",b"campaign_bidding_strategy",u"campaign_budget",b"campaign_budget",u"commission",b"commission",u"dynamic_search_ads_setting",b"dynamic_search_ads_setting",u"end_date",b"end_date",u"final_url_suffix",b"final_url_suffix",u"geo_target_type_setting",b"geo_target_type_setting",u"hotel_setting",b"hotel_setting",u"id",b"id",u"manual_cpc",b"manual_cpc",u"manual_cpm",b"manual_cpm",u"manual_cpv",b"manual_cpv",u"maximize_conversion_value",b"maximize_conversion_value",u"maximize_conversions",b"maximize_conversions",u"name",b"name",u"network_settings",b"network_settings",u"percent_cpc",b"percent_cpc",u"real_time_bidding_setting",b"real_time_bidding_setting",u"selective_optimization",b"selective_optimization",u"shopping_setting",b"shopping_setting",u"start_date",b"start_date",u"target_cpa",b"target_cpa",u"target_cpm",b"target_cpm",u"target_impression_share",b"target_impression_share",u"target_roas",b"target_roas",u"target_spend",b"target_spend",u"targeting_setting",b"targeting_setting",u"tracking_setting",b"tracking_setting",u"tracking_url_template",b"tracking_url_template",u"vanity_pharma",b"vanity_pharma"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"ad_serving_optimization_status",b"ad_serving_optimization_status",u"advertising_channel_sub_type",b"advertising_channel_sub_type",u"advertising_channel_type",b"advertising_channel_type",u"app_campaign_setting",b"app_campaign_setting",u"base_campaign",b"base_campaign",u"bidding_strategy",b"bidding_strategy",u"bidding_strategy_type",b"bidding_strategy_type",u"campaign_bidding_strategy",b"campaign_bidding_strategy",u"campaign_budget",b"campaign_budget",u"commission",b"commission",u"dynamic_search_ads_setting",b"dynamic_search_ads_setting",u"end_date",b"end_date",u"experiment_type",b"experiment_type",u"final_url_suffix",b"final_url_suffix",u"frequency_caps",b"frequency_caps",u"geo_target_type_setting",b"geo_target_type_setting",u"hotel_setting",b"hotel_setting",u"id",b"id",u"labels",b"labels",u"manual_cpc",b"manual_cpc",u"manual_cpm",b"manual_cpm",u"manual_cpv",b"manual_cpv",u"maximize_conversion_value",b"maximize_conversion_value",u"maximize_conversions",b"maximize_conversions",u"name",b"name",u"network_settings",b"network_settings",u"payment_mode",b"payment_mode",u"percent_cpc",b"percent_cpc",u"real_time_bidding_setting",b"real_time_bidding_setting",u"resource_name",b"resource_name",u"selective_optimization",b"selective_optimization",u"serving_status",b"serving_status",u"shopping_setting",b"shopping_setting",u"start_date",b"start_date",u"status",b"status",u"target_cpa",b"target_cpa",u"target_cpm",b"target_cpm",u"target_impression_share",b"target_impression_share",u"target_roas",b"target_roas",u"target_spend",b"target_spend",u"targeting_setting",b"targeting_setting",u"tracking_setting",b"tracking_setting",u"tracking_url_template",b"tracking_url_template",u"url_custom_parameters",b"url_custom_parameters",u"vanity_pharma",b"vanity_pharma",u"video_brand_safety_suitability",b"video_brand_safety_suitability"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"campaign_bidding_strategy",b"campaign_bidding_strategy"]) -> typing_extensions___Literal["bidding_strategy","commission","manual_cpc","manual_cpm","manual_cpv","maximize_conversions","maximize_conversion_value","target_cpa","target_impression_share","target_roas","target_spend","percent_cpc","target_cpm"]: ...
global___Campaign = Campaign



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.enums.page_one_promoted_strategy_goal_pb2 import (
    PageOnePromotedStrategyGoalEnum as google___ads___googleads___v1___enums___page_one_promoted_strategy_goal_pb2___PageOnePromotedStrategyGoalEnum,
)

from google.ads.google_ads.v1.proto.enums.target_impression_share_location_pb2 import (
    TargetImpressionShareLocationEnum as google___ads___googleads___v1___enums___target_impression_share_location_pb2___TargetImpressionShareLocationEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int32Value as google___protobuf___wrappers_pb2___Int32Value,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class Commission(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def commission_rate_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        commission_rate_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> Commission: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"commission_rate_micros"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"commission_rate_micros"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"commission_rate_micros",b"commission_rate_micros"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"commission_rate_micros",b"commission_rate_micros"]) -> None: ...

class EnhancedCpc(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> EnhancedCpc: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...

class ManualCpc(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def enhanced_cpc_enabled(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    def __init__(self,
        *,
        enhanced_cpc_enabled : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ManualCpc: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"enhanced_cpc_enabled"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"enhanced_cpc_enabled"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"enhanced_cpc_enabled",b"enhanced_cpc_enabled"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"enhanced_cpc_enabled",b"enhanced_cpc_enabled"]) -> None: ...

class ManualCpm(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ManualCpm: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...

class ManualCpv(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ManualCpv: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...

class MaximizeConversions(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MaximizeConversions: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...

class MaximizeConversionValue(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def target_roas(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    def __init__(self,
        *,
        target_roas : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MaximizeConversionValue: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"target_roas"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"target_roas"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"target_roas",b"target_roas"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"target_roas",b"target_roas"]) -> None: ...

class PageOnePromoted(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    strategy_goal = ... # type: google___ads___googleads___v1___enums___page_one_promoted_strategy_goal_pb2___PageOnePromotedStrategyGoalEnum.PageOnePromotedStrategyGoal

    @property
    def cpc_bid_ceiling_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def bid_modifier(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def only_raise_cpc_bids(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def raise_cpc_bid_when_budget_constrained(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def raise_cpc_bid_when_quality_score_is_low(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    def __init__(self,
        *,
        strategy_goal : typing___Optional[google___ads___googleads___v1___enums___page_one_promoted_strategy_goal_pb2___PageOnePromotedStrategyGoalEnum.PageOnePromotedStrategyGoal] = None,
        cpc_bid_ceiling_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        bid_modifier : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        only_raise_cpc_bids : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        raise_cpc_bid_when_budget_constrained : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        raise_cpc_bid_when_quality_score_is_low : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> PageOnePromoted: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"bid_modifier",u"cpc_bid_ceiling_micros",u"only_raise_cpc_bids",u"raise_cpc_bid_when_budget_constrained",u"raise_cpc_bid_when_quality_score_is_low"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"bid_modifier",u"cpc_bid_ceiling_micros",u"only_raise_cpc_bids",u"raise_cpc_bid_when_budget_constrained",u"raise_cpc_bid_when_quality_score_is_low",u"strategy_goal"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"bid_modifier",b"bid_modifier",u"cpc_bid_ceiling_micros",b"cpc_bid_ceiling_micros",u"only_raise_cpc_bids",b"only_raise_cpc_bids",u"raise_cpc_bid_when_budget_constrained",b"raise_cpc_bid_when_budget_constrained",u"raise_cpc_bid_when_quality_score_is_low",b"raise_cpc_bid_when_quality_score_is_low"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"bid_modifier",b"bid_modifier",u"cpc_bid_ceiling_micros",b"cpc_bid_ceiling_micros",u"only_raise_cpc_bids",b"only_raise_cpc_bids",u"raise_cpc_bid_when_budget_constrained",b"raise_cpc_bid_when_budget_constrained",u"raise_cpc_bid_when_quality_score_is_low",b"raise_cpc_bid_when_quality_score_is_low",u"strategy_goal",b"strategy_goal"]) -> None: ...

class TargetCpa(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def target_cpa_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def cpc_bid_ceiling_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def cpc_bid_floor_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        target_cpa_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        cpc_bid_ceiling_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        cpc_bid_floor_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> TargetCpa: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"cpc_bid_ceiling_micros",u"cpc_bid_floor_micros",u"target_cpa_micros"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"cpc_bid_ceiling_micros",u"cpc_bid_floor_micros",u"target_cpa_micros"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"cpc_bid_ceiling_micros",b"cpc_bid_ceiling_micros",u"cpc_bid_floor_micros",b"cpc_bid_floor_micros",u"target_cpa_micros",b"target_cpa_micros"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"cpc_bid_ceiling_micros",b"cpc_bid_ceiling_micros",u"cpc_bid_floor_micros",b"cpc_bid_floor_micros",u"target_cpa_micros",b"target_cpa_micros"]) -> None: ...

class TargetCpm(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> TargetCpm: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...

class TargetImpressionShare(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    location = ... # type: google___ads___googleads___v1___enums___target_impression_share_location_pb2___TargetImpressionShareLocationEnum.TargetImpressionShareLocation

    @property
    def location_fraction_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def cpc_bid_ceiling_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        location : typing___Optional[google___ads___googleads___v1___enums___target_impression_share_location_pb2___TargetImpressionShareLocationEnum.TargetImpressionShareLocation] = None,
        location_fraction_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        cpc_bid_ceiling_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> TargetImpressionShare: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"cpc_bid_ceiling_micros",u"location_fraction_micros"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"cpc_bid_ceiling_micros",u"location",u"location_fraction_micros"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"cpc_bid_ceiling_micros",b"cpc_bid_ceiling_micros",u"location_fraction_micros",b"location_fraction_micros"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"cpc_bid_ceiling_micros",b"cpc_bid_ceiling_micros",u"location",b"location",u"location_fraction_micros",b"location_fraction_micros"]) -> None: ...

class TargetOutrankShare(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def target_outrank_share_micros(self) -> google___protobuf___wrappers_pb2___Int32Value: ...

    @property
    def competitor_domain(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def cpc_bid_ceiling_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def only_raise_cpc_bids(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def raise_cpc_bid_when_quality_score_is_low(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    def __init__(self,
        *,
        target_outrank_share_micros : typing___Optional[google___protobuf___wrappers_pb2___Int32Value] = None,
        competitor_domain : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        cpc_bid_ceiling_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        only_raise_cpc_bids : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        raise_cpc_bid_when_quality_score_is_low : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> TargetOutrankShare: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"competitor_domain",u"cpc_bid_ceiling_micros",u"only_raise_cpc_bids",u"raise_cpc_bid_when_quality_score_is_low",u"target_outrank_share_micros"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"competitor_domain",u"cpc_bid_ceiling_micros",u"only_raise_cpc_bids",u"raise_cpc_bid_when_quality_score_is_low",u"target_outrank_share_micros"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"competitor_domain",b"competitor_domain",u"cpc_bid_ceiling_micros",b"cpc_bid_ceiling_micros",u"only_raise_cpc_bids",b"only_raise_cpc_bids",u"raise_cpc_bid_when_quality_score_is_low",b"raise_cpc_bid_when_quality_score_is_low",u"target_outrank_share_micros",b"target_outrank_share_micros"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"competitor_domain",b"competitor_domain",u"cpc_bid_ceiling_micros",b"cpc_bid_ceiling_micros",u"only_raise_cpc_bids",b"only_raise_cpc_bids",u"raise_cpc_bid_when_quality_score_is_low",b"raise_cpc_bid_when_quality_score_is_low",u"target_outrank_share_micros",b"target_outrank_share_micros"]) -> None: ...

class TargetRoas(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def target_roas(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def cpc_bid_ceiling_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def cpc_bid_floor_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        target_roas : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        cpc_bid_ceiling_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        cpc_bid_floor_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> TargetRoas: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"cpc_bid_ceiling_micros",u"cpc_bid_floor_micros",u"target_roas"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"cpc_bid_ceiling_micros",u"cpc_bid_floor_micros",u"target_roas"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"cpc_bid_ceiling_micros",b"cpc_bid_ceiling_micros",u"cpc_bid_floor_micros",b"cpc_bid_floor_micros",u"target_roas",b"target_roas"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"cpc_bid_ceiling_micros",b"cpc_bid_ceiling_micros",u"cpc_bid_floor_micros",b"cpc_bid_floor_micros",u"target_roas",b"target_roas"]) -> None: ...

class TargetSpend(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def target_spend_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def cpc_bid_ceiling_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        target_spend_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        cpc_bid_ceiling_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> TargetSpend: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"cpc_bid_ceiling_micros",u"target_spend_micros"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"cpc_bid_ceiling_micros",u"target_spend_micros"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"cpc_bid_ceiling_micros",b"cpc_bid_ceiling_micros",u"target_spend_micros",b"target_spend_micros"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"cpc_bid_ceiling_micros",b"cpc_bid_ceiling_micros",u"target_spend_micros",b"target_spend_micros"]) -> None: ...

class PercentCpc(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def cpc_bid_ceiling_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def enhanced_cpc_enabled(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    def __init__(self,
        *,
        cpc_bid_ceiling_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        enhanced_cpc_enabled : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> PercentCpc: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"cpc_bid_ceiling_micros",u"enhanced_cpc_enabled"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"cpc_bid_ceiling_micros",u"enhanced_cpc_enabled"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"cpc_bid_ceiling_micros",b"cpc_bid_ceiling_micros",u"enhanced_cpc_enabled",b"enhanced_cpc_enabled"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"cpc_bid_ceiling_micros",b"cpc_bid_ceiling_micros",u"enhanced_cpc_enabled",b"enhanced_cpc_enabled"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.enums.extension_setting_device_pb2 import (
    ExtensionSettingDeviceEnum as google___ads___googleads___v2___enums___extension_setting_device_pb2___ExtensionSettingDeviceEnum,
)

from google.ads.google_ads.v2.proto.enums.extension_type_pb2 import (
    ExtensionTypeEnum as google___ads___googleads___v2___enums___extension_type_pb2___ExtensionTypeEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class AdGroupExtensionSetting(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    extension_type = ... # type: google___ads___googleads___v2___enums___extension_type_pb2___ExtensionTypeEnum.ExtensionType
    device = ... # type: google___ads___googleads___v2___enums___extension_setting_device_pb2___ExtensionSettingDeviceEnum.ExtensionSettingDevice

    @property
    def ad_group(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def extension_feed_items(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        extension_type : typing___Optional[google___ads___googleads___v2___enums___extension_type_pb2___ExtensionTypeEnum.ExtensionType] = None,
        ad_group : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        extension_feed_items : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
        device : typing___Optional[google___ads___googleads___v2___enums___extension_setting_device_pb2___ExtensionSettingDeviceEnum.ExtensionSettingDevice] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AdGroupExtensionSetting: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"ad_group"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group",u"device",u"extension_feed_items",u"extension_type",u"resource_name"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"ad_group",b"ad_group"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group",b"ad_group",u"device",b"device",u"extension_feed_items",b"extension_feed_items",u"extension_type",b"extension_type",u"resource_name",b"resource_name"]) -> None: ...



from typing import Any, Optional, Tuple, Dict, List, NamedTuple

import grpc  # type: ignore

class _ClientCallDetails(NamedTuple(
                '_ClientCallDetails',
                [('method', str), ('timeout', float), ('metadata', List[Tuple[str, Any]]), ('credentials', Optional[grpc.CallCredentials])]),
    grpc.ClientCallDetails):
    pass


class InterceptorMixin:
    @classmethod
    def get_request_id_from_metadata(self, trailing_metadata: Tuple[Tuple[str, Any], ...]) -> Optional[str]: ...
    @classmethod
    def parse_metadata_to_json(self, metadata: Tuple[Tuple[str, Any], ...]) -> str: ...
    @classmethod
    def format_json_object(self, obj: Dict[str, Any]) -> str: ...
    @classmethod
    def get_trailing_metadata_from_interceptor_exception(self, exception: grpc.Call) -> Tuple[Tuple[str, Any], ...]: ...
    @classmethod
    def get_client_call_details_instance(cls, method: str, timeout: float, metadata: List[Tuple[str, Any]], credentials: Optional[grpc.CallCredentials] = ...) -> _ClientCallDetails: ...



# Stubs for google.ads.google_ads.v2.proto.services.campaign_experiment_service_pb2_grpc (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

class CampaignExperimentServiceStub:
    GetCampaignExperiment: Any = ...
    CreateCampaignExperiment: Any = ...
    MutateCampaignExperiments: Any = ...
    GraduateCampaignExperiment: Any = ...
    PromoteCampaignExperiment: Any = ...
    EndCampaignExperiment: Any = ...
    ListCampaignExperimentAsyncErrors: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CampaignExperimentServiceServicer:
    def GetCampaignExperiment(self, request: Any, context: Any) -> None: ...
    def CreateCampaignExperiment(self, request: Any, context: Any) -> None: ...
    def MutateCampaignExperiments(self, request: Any, context: Any) -> None: ...
    def GraduateCampaignExperiment(self, request: Any, context: Any) -> None: ...
    def PromoteCampaignExperiment(self, request: Any, context: Any) -> None: ...
    def EndCampaignExperiment(self, request: Any, context: Any) -> None: ...
    def ListCampaignExperimentAsyncErrors(self, request: Any, context: Any) -> None: ...

def add_CampaignExperimentServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# Stubs for google.ads.google_ads.v2.proto.services.campaign_criterion_simulation_service_pb2_grpc (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

class CampaignCriterionSimulationServiceStub:
    GetCampaignCriterionSimulation: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CampaignCriterionSimulationServiceServicer:
    def GetCampaignCriterionSimulation(self, request: Any, context: Any) -> None: ...

def add_CampaignCriterionSimulationServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
